# scTrace+

[![PyPI version](https://badge.fury.io/py/scTrace.svg)](https://pypi.org/project/scTrace/)

## Introduction
`scTrace+` is a computational method to enhance the cell fate inference by integrating the lineage-tracing and multi-faceted transcriptomic similarity information.

## System Requirements
- Python version: >= 3.7

## Installation

The Release version `scTrace+` python package can be installed directly via pip:
```
pip install scTrace
```
